@@ -11,9 +11,8 @@ def get_args():
 
 
 def main():
-    sp.call("wget https://raw.githubusercontent.com/Doraemon-desu/J-league/main/J-league.csv",shell=True)
     args = get_args()
-    df = pd.read_csv('J-league.csv',encoding='utf-8',index_col='team')
+    df = pd.read_csv('https://raw.githubusercontent.com/Doraemon-desu/J-league/main/J-league.csv',encoding='utf-8',index_col='team')
     name = args.team
     victory = df.loc[name,:]
     x = df.columns.values
